@@ -96,7 +96,7 @@ getRealizationBackend <- function()
     getAutoRealizationBackend()
 }
 
-.SUPPORTED_REALIZATION_BACKENDS <- data.frame(
+.REGISTERED_REALIZATION_BACKENDS <- data.frame(
     BACKEND=c("RleArray", "HDF5Array", "TENxMatrix"),
     package=c("DelayedArray", "HDF5Array", "HDF5Array"),
     realization_sink_class=c("RleRealizationSink",
@@ -105,9 +105,9 @@ getRealizationBackend <- function()
     stringsAsFactors=FALSE
 )
 
-supportedRealizationBackends <- function()
+registeredRealizationBackends <- function()
 {
-    ans <- .SUPPORTED_REALIZATION_BACKENDS[ , c("BACKEND", "package")]
+    ans <- .REGISTERED_REALIZATION_BACKENDS[ , c("BACKEND", "package")]
     backend <- getAutoRealizationBackend()
     Lcol <- ifelse(ans[ , "BACKEND"] %in% backend, "->", "")
     Rcol <- ifelse(ans[ , "BACKEND"] %in% backend, "<-", "")
@@ -116,17 +116,25 @@ supportedRealizationBackends <- function()
           data.frame(` `=Rcol, check.names=FALSE))
 }
 
+supportedRealizationBackends <- function()
+{
+    .Deprecated("registeredRealizationBackends")
+    registeredRealizationBackends()
+}
+
 ### NOT exported.
 load_BACKEND_package <- function(BACKEND)
 {
     if (!isSingleString(BACKEND))
         stop(wmsg("'BACKEND' must be a single string or NULL"))
-    backends <- .SUPPORTED_REALIZATION_BACKENDS
+    backends <- .REGISTERED_REALIZATION_BACKENDS
     m <- match(BACKEND, backends[ , "BACKEND"])
     if (is.na(m))
-        stop(wmsg("\"", BACKEND, "\" is not a supported backend. Please ",
-                  "use supportedRealizationBackends() to get the list of ",
-                  "\"realization backends\" that are currently supported."))
+        stop(wmsg("Realization backend ", BACKEND, " is not registered ",
+                  "in the DelayedArray package. Please use ",
+                  "registeredRealizationBackends() to get the list of ",
+                  "realization backends that are currently registered ",
+                  "in the package."))
     package <- backends[ , "package"][[m]]
     class_package <- attr(BACKEND, "package")
     if (is.null(class_package)) {
@@ -134,9 +142,10 @@ load_BACKEND_package <- function(BACKEND)
     } else if (!identical(package, class_package)) {
         stop(wmsg("\"package\" attribute on supplied 'BACKEND' is ",
                   "inconsistent with package normally associated with ",
-                  "this backend"))
+                  "this realization backend"))
     }
-    library(package, character.only=TRUE)
+    S4Arrays:::load_package_gracefully(package, "using the ",
+                                       BACKEND, " realization backend")
     stopifnot(getClass(BACKEND)@package == package)
 }
 
@@ -159,7 +168,7 @@ load_BACKEND_package <- function(BACKEND)
 
 .get_realization_sink_constructor <- function(BACKEND)
 {
-    backends <- .SUPPORTED_REALIZATION_BACKENDS
+    backends <- .REGISTERED_REALIZATION_BACKENDS
     m <- match(BACKEND, backends[ , "BACKEND"])
     realization_sink_class <- backends[ , "realization_sink_class"][[m]]
     package <- backends[ , "package"][[m]]
@@ -213,21 +222,31 @@ setRealizationBackend <- function(...)
     auto_realization_sink_constructor
 }
 
-AutoRealizationSink <- function(dim, dimnames=NULL, type="double",
-                                as.sparse=FALSE)
+.AutoRealizationSink <- function(dim, dimnames=NULL, type="double",
+                                 as.sparse=FALSE, ...)
 {
     realization_sink_constructor <- .get_auto_realization_sink_constructor()
     args <- list(dim, dimnames, type)
     formal_args <- formalArgs(realization_sink_constructor)
     if (length(formal_args) >= 4L && formal_args[[4L]] == "as.sparse")
         args <- c(args, list(as.sparse=as.sparse))
+    args <- c(args, list(...))
     do.call(realization_sink_constructor, args)
 }
 
-RealizationSink <- function(...)
+AutoRealizationSink <- function(dim, dimnames=NULL, type="double",
+                                as.sparse=FALSE)
 {
-    .Defunct("AutoRealizationSink")
-    AutoRealizationSink(...)
+    .AutoRealizationSink(dim, dimnames, type, as.sparse)
+}
+
+### Not exported.
+RealizationSink <- function(BACKEND, ...)
+{
+    OLD_BACKEND <- getAutoRealizationBackend()
+    setAutoRealizationBackend(BACKEND)
+    on.exit(setAutoRealizationBackend(OLD_BACKEND))
+    .AutoRealizationSink(...)
 }
 
 
