@@ -36,6 +36,8 @@ BLOCK_write_to_sink <- function(sink, x, verbose=NA)
         } else {
             block <- read_block(x, viewport, as.sparse=NA)
         }
+        ## 'block' is either an ordinary array or SparseArray derivative
+        ## (SVT_SparseArray or COO_SparseArray object).
         if (verbose)
             message("\\ Writing it ... ", appendLF=FALSE)
         sink <- write_block(sink, viewport, block)
@@ -54,19 +56,34 @@ BLOCK_write_to_sink <- function(sink, x, verbose=NA)
 
 setGeneric("realize", function(x, ...) standardGeneric("realize"))
 
+### Realize an array-like object in memory if 'BACKEND' is NULL, otherwise
+### on disk.
+### Note that, when 'BACKEND' is not NULL, 'x' gets realized as a "pristine"
+### DelayedArray object (e.g. an HDF5Array object), that is, as a DelayedArray
+### object that carries no delayed operations. This means that if 'x' is a
+### DelayedArray object, the returned object is another DelayedArray object
+### that is semantically equivalent to 'x' but where the delayed operations
+### carried by 'x' have been realized.
+### Will raise an error if 'x' is not an array-like object. Non array-like
+### objects (e.g. SummarizedExperiment objects) need to have their own
+### realize() method.
 setMethod("realize", "ANY",
     function(x, BACKEND=getAutoRealizationBackend())
     {
-        x <- DelayedArray(x)
-        if (is.null(BACKEND))
-            return(DelayedArray(as.array(x)))
-        load_BACKEND_package(BACKEND)
-        ans <- as(x, BACKEND)
-        ## Temporarily needed because coercion to HDF5Array currently drops
-        ## the dimnames. See R/writeHDF5Array.R in the HDF5Array package for
-        ## more information about this.
-        ## TODO: Remove line below when this is addressed.
-        S4Arrays:::set_dimnames(ans, dimnames(x))
+        if (is.null(dim(x)))
+            stop(wmsg("realization of ", class(x)[[1L]], " objects ",
+                      "is not supported"))
+        if (!is.null(BACKEND)) {
+            load_BACKEND_package(BACKEND)
+            return(as(x, BACKEND))
+        }
+        if (is_sparse(x)) {
+            as(x, "SVT_SparseArray")
+        } else {
+            ## When 'BACKEND' is NULL, realize() will act as a no-op on an
+            ## ordinary matrix or array.
+            as.array(x)
+        }
     }
 )
 
