@@ -1,52 +1,51 @@
 #setAutoRealizationBackend("RleArray")
 #setAutoRealizationBackend("HDF5Array")
 
-.ARITH_MEMBERS <- c("+", "-", "*", "/", "^", "%%", "%/%")
-.COMPARE_MEMBERS <- c("==", "!=", "<=", ">=", "<", ">")
-.LOGIC_MEMBERS <- c("&", "|")  # currently untested
+ARITH_OPS   <- c("+", "-", "*", "/", "^", "%%", "%/%")
+COMPARE_OPS <- c("==", "!=", "<=", ">=", "<", ">")
+LOGIC_OPS   <- c("&", "|")  # currently untested
 
-### Toy integer 3D SparseArraySeed.
-.make_toy_sas1 <- function()
+### Toy integer 3D SVT_SparseArray.
+.make_toy_svt1 <- function()
 {
     dim1 <- c(5L, 10L, 3L)
-    nzindex1 <- Lindex2Mindex(1:prod(dim1), dim1)
+    svt1 <- SVT_SparseArray(dim=dim1)
+    nzvals1 <- 24:-9
+    nzvals1[2:3] <- NA
+    nzvals1[4:5] <- 0L
     set.seed(123)
-    nzindex1 <- nzindex1[sample(nrow(nzindex1), 30), , drop=FALSE]
-    nzdata1 <- 24:-5
-    nzdata1[2:3] <- NA
-    nzdata1[4:5] <- 0L
-    SparseArraySeed(dim1, nzindex1, nzdata1)
+    svt1[sample(length(svt1), length(nzvals1))] <- nzvals1
+    svt1
 }
 
-### Toy integer 3D SparseArraySeed with no zeros or NAs.
-.make_toy_sas1b <- function()
+### Toy integer 3D array with no zeros or NAs.
+.make_toy_a1b <- function()
 {
     dim1b <- c(5L, 10L, 3L)
-    nzindex1b <- Lindex2Mindex(1:prod(dim1b), dim1b)
     set.seed(123)
-    nzindex1b <- nzindex1b[sample(nrow(nzindex1b)), , drop=FALSE]
-    nzdata1b <- sample(10L, nrow(nzindex1b), replace=TRUE)
-    SparseArraySeed(dim1b, nzindex1b, nzdata1b)
+    array(sample(10L, prod(dim1b), replace=TRUE), dim1b)
 }
 
 ### Toy numeric 3D array with one NA and plenty of zeros, Inf's, -Inf's,
 ### and NaN's.
 .make_toy_a2 <- function()
 {
-    a1b <- as.array(.make_toy_sas1b())
+    a1b <- .make_toy_a1b()
     a2 <- 2:-2 / (a1b - 5)
     a2[2, 9, 2] <- NA  # same as a2[[92]] <- NA
     a2
 }
 
-### Toy character 3D SparseArraySeed.
-.make_toy_sas3 <- function()
+### Toy character 3D SVT_SparseArray.
+.make_toy_svt3 <- function()
 {
-    sas1 <- .make_toy_sas1()
-    nzdata3 <- paste0(sas1@nzdata, "aXb")
-    nzdata3[2:3] <- NA
-    nzdata3[4:5] <- ""
-    SparseArraySeed(dim(sas1), sas1@nzindex, nzdata3)
+    svt3 <- .make_toy_svt1()
+    nzvals3 <- nzvals(svt3)
+    nzvals3 <- paste0(nzvals3, "aXb")
+    nzvals3[2:3] <- NA
+    nzvals3[4:5] <- ""
+    nzvals(svt3) <- nzvals3
+    svt3
 }
 
 .BLOCK_SIZES1 <- c(12L, 20L, 50L, 15000L)
@@ -62,17 +61,17 @@ test_DelayedArray_unary_iso_ops <- function()
         checkIdentical(GENERIC(a), as.array(current))
     }
 
-    a1 <- as.array(.make_toy_sas1())  # integer 3D array
-    A1 <- realize(a1)
+    a1 <- as.array(.make_toy_svt1())  # integer 3D array
+    A1 <- DelayedArray(realize(a1))
     a2 <- .make_toy_a2()  # numeric 3D array
-    A2 <- realize(a2)
+    A2 <- DelayedArray(realize(a2))
     for (.Generic in c("is.na", "is.finite", "is.infinite", "is.nan")) {
         do_tests(.Generic, a1, A1)
         do_tests(.Generic, a2, A2)
     }
 
-    a3 <- as.array(.make_toy_sas3())  # character 3D array
-    A3 <- realize(a3)
+    a3 <- as.array(.make_toy_svt3())  # character 3D array
+    A3 <- DelayedArray(realize(a3))
     for (.Generic in c("nchar", "tolower", "toupper")) {
         do_tests(.Generic, a3, A3)
     }
@@ -108,29 +107,29 @@ test_DelayedArray_Math_ans_Arith <- function()
         checkIdentical(toto1(target2), as.array(current))
     }
 
-    a1 <- as.array(.make_toy_sas1())  # integer 3D array
-    A1 <- realize(a1)
+    a1 <- as.array(.make_toy_svt1())  # integer 3D array
+    A1 <- DelayedArray(realize(a1))
     a2 <- .make_toy_a2()  # numeric 3D array
-    A2 <- realize(a2)
+    A2 <- DelayedArray(realize(a2))
     do_tests(a1, A1)
     do_tests(a2, A2)
 
     a <- a1[ , 10:4, -2]
     A <- A1[ , 10:4, -2]
     do_tests(a, A)
-    do_tests(a, realize(A))
+    do_tests(a, DelayedArray(realize(A)))
     a <- a2[ , 10:4, -2]
     A <- A2[ , 10:4, -2]
     do_tests(a, A)
-    do_tests(a, realize(A))
+    do_tests(a, DelayedArray(realize(A)))
 
     ## with a numeric matrix
     m <- a2[ , , 2]
     M <- A2[ , , 2]
     do_tests(m, M)
-    do_tests(m, realize(M))
+    do_tests(m, DelayedArray(realize(M)))
     do_tests(t(m), t(M))
-    do_tests(t(m), realize(t(M)))
+    do_tests(t(m), DelayedArray(realize(t(M))))
     checkIdentical(t(toto1(m)), as.matrix(t(toto1(M))))
 }
 
@@ -166,31 +165,31 @@ test_DelayedArray_Ops_with_left_or_right_vector <- function()
     }
 
     a2 <- .make_toy_a2()  # numeric 3D array
-    A2 <- realize(a2)
+    A2 <- DelayedArray(realize(a2))
     m <- a2[ , , 2]
-    M <- realize(m)
-    for (.Generic in c(.ARITH_MEMBERS, .COMPARE_MEMBERS))
+    M <- DelayedArray(realize(m))
+    for (.Generic in c(ARITH_OPS, COMPARE_OPS))
         do_tests(.Generic, a2, A2, m, M)
 
-    a1 <- as.array(.make_toy_sas1())  # integer 3D array
+    a1 <- as.array(.make_toy_svt1())  # integer 3D array
     a <- a1 >= 1L  # logical 3D array
-    A <- realize(a)
+    A <- DelayedArray(realize(a))
     m <- a[ , , 2]
-    M <- realize(m)
-    for (.Generic in .LOGIC_MEMBERS)
+    M <- DelayedArray(realize(m))
+    for (.Generic in LOGIC_OPS)
         do_tests(.Generic, a2, A2, m, M)
 }
 
 test_DelayedArray_Ops_with_conformable_args <- function()
 {
-    a1 <- as.array(.make_toy_sas1())  # integer 3D array
-    A1 <- realize(a1)
+    a1 <- as.array(.make_toy_svt1())  # integer 3D array
+    A1 <- DelayedArray(realize(a1))
     a2 <- .make_toy_a2()  # numeric 3D array
-    A2 <- realize(a2)
+    A2 <- DelayedArray(realize(a2))
     a3 <- array(sample(5L, 150, replace=TRUE), c(5, 10, 3))
     a3[2, 9, 2] <- NA  # same as a3[[92]] <- NA
-    A3 <- realize(a3)
-    for (.Generic in c(.ARITH_MEMBERS, .COMPARE_MEMBERS)) {
+    A3 <- DelayedArray(realize(a3))
+    for (.Generic in c(ARITH_OPS, COMPARE_OPS)) {
         GENERIC <- match.fun(.Generic)
         target1 <- GENERIC(a1, a2)
         target2 <- GENERIC(a2, a1)
@@ -201,10 +200,10 @@ test_DelayedArray_Ops_with_conformable_args <- function()
     }
 
     x <- a1 >= 6L  # logical 3D array
-    X <- realize(x)
+    X <- DelayedArray(realize(x))
     y <- a1 >= 1L & a1 <= 10L  # logical 3D array
-    Y <- realize(y)
-    for (.Generic in .LOGIC_MEMBERS) {
+    Y <- DelayedArray(realize(y))
+    for (.Generic in LOGIC_OPS) {
         GENERIC <- match.fun(.Generic)
         target <- GENERIC(x, y)
         checkIdentical(target, as.array(GENERIC(X, Y)))
@@ -212,15 +211,85 @@ test_DelayedArray_Ops_with_conformable_args <- function()
     }
 }
 
+test_DelayedMatrix_Ops <- function()
+{
+    test_delayed_Ops_on_matrix <- function(.Generic, m, M) {
+        GENERIC <- match.fun(.Generic)
+
+        target_current <- list(
+            list(GENERIC(m, m[ , 1]), GENERIC(M, M[ , 1])),
+            list(GENERIC(m[ , 2], m), GENERIC(M[ , 2], M))
+        )
+        for (i in seq_along(target_current)) {
+            target <- target_current[[i]][[1L]]
+            current <- target_current[[i]][[2L]]
+            checkIdentical(target, as.matrix(current))
+            checkIdentical(t(target), as.matrix(t(current)))
+            checkIdentical(target[-2, 8:5], as.matrix(current[-2, 8:5]))
+            checkIdentical(t(target[-2, 8:5]), as.matrix(t(current[-2, 8:5])))
+            checkIdentical(target[-2, 0], as.matrix(current[-2, 0]))
+            checkIdentical(t(target[-2, 0]), as.matrix(t(current[-2, 0])))
+            checkIdentical(target[0, ], as.matrix(current[0, ]))
+            checkIdentical(t(target[0, ]), as.matrix(t(current[0, ])))
+        }
+
+        target_current <- list(
+            list(GENERIC(t(m), 8:-1), GENERIC(t(M), 8:-1)),
+            list(GENERIC(8:-1, t(m)), GENERIC(8:-1, t(M))),
+
+            list(GENERIC(t(m), m[1 , ]), GENERIC(t(M), M[1 , ])),
+            list(GENERIC(m[2 , ], t(m)), GENERIC(M[2 , ], t(M))),
+
+            list(GENERIC(t(m), m[1 , 6:10]), GENERIC(t(M), M[1 , 6:10])),
+            list(GENERIC(m[2 , 8:7], t(m)), GENERIC(M[2 , 8:7], t(M)))
+        )
+        for (i in seq_along(target_current)) {
+            target <- target_current[[i]][[1L]]
+            current <- target_current[[i]][[2L]]
+            checkIdentical(target, as.matrix(current))
+            checkIdentical(target[1:3 , ], as.matrix(current[1:3 , ]))
+            checkIdentical(target[ , 1:3], as.matrix(current[ , 1:3]))
+            checkIdentical(t(target), as.matrix(t(current)))
+            checkIdentical(t(target)[1:3 , ], as.matrix(t(current)[1:3 , ]))
+            checkIdentical(t(target)[ , 1:3], as.matrix(t(current)[ , 1:3]))
+            checkIdentical(target[8:5, -2], as.matrix(current[8:5, -2]))
+            checkIdentical(t(target[8:5, -2]), as.matrix(t(current[8:5, -2])))
+            checkIdentical(target[0, -2], as.matrix(current[0, -2]))
+            checkIdentical(t(target[0, -2]), as.matrix(t(current[0, -2])))
+            checkIdentical(target[ , 0], as.matrix(current[ , 0]))
+            checkIdentical(t(target[ , 0]), as.matrix(t(current[ , 0])))
+        }
+    }
+
+    a <- array(sample(5L, 150, replace=TRUE), c(5, 10, 3))  # integer array
+    a <- a + runif(150) - 0.5                               # numeric array
+    a[2, 9, 2] <- NA  # same as a[[92]] <- NA
+
+    toto <- function(x) t((5 * x[ , 1:2] ^ 3 + 1L) * log(x)[, 10:9])[ , -1]
+
+    m <- a[ , , 2]
+    M <- DelayedArray(realize(m))
+    checkIdentical(toto(m), as.array(toto(M)))
+    ## Logic ops currently untested.
+    for (.Generic in c(ARITH_OPS, COMPARE_OPS))
+        test_delayed_Ops_on_matrix(.Generic, m, M)
+
+    M <- DelayedArray(realize(a))[ , , 2]
+    checkIdentical(toto(m), as.array(toto(M)))
+    ## Logic ops currently untested.
+    for (.Generic in c(ARITH_OPS, COMPARE_OPS))
+        test_delayed_Ops_on_matrix(.Generic, m, M)
+}
+
 test_DelayedArray_anyNA <- function()
 {
     on.exit(suppressMessages(setAutoBlockSize()))
     BLOCK_anyNA <- DelayedArray:::.BLOCK_anyNA
 
-    a1 <- as.array(.make_toy_sas1())   # integer 3D array
-    A1 <- realize(a1)
-    a1b <- as.array(.make_toy_sas1b()) # integer 3D array with no zeros or NAs
-    A1b <- realize(a1b)
+    a1 <- as.array(.make_toy_svt1())   # integer 3D array
+    A1 <- DelayedArray(realize(a1))
+    a1b <- .make_toy_a1b()  # integer 3D array with no zeros or NAs
+    A1b <- DelayedArray(realize(a1b))
 
     for (block_size in .BLOCK_SIZES1) {
         suppressMessages(setAutoBlockSize(block_size))
@@ -233,31 +302,67 @@ test_DelayedArray_anyNA <- function()
 
 test_DelayedArray_which <- function()
 {
-    on.exit(suppressMessages(setAutoBlockSize()))
-    BLOCK_which <- DelayedArray:::BLOCK_which
-
-    a1 <- as.array(.make_toy_sas1())  # integer 3D array
-    a <- a1 >= 1L  # logical 3D array
-    A <- realize(a)
-    target1 <- which(a)
-    target2 <- which(a, arr.ind=TRUE, useNames=FALSE)
-    for (block_size in .BLOCK_SIZES1) {
-        suppressMessages(setAutoBlockSize(block_size))
-        checkIdentical(target1, which(A))
-        checkIdentical(target2, which(A, arr.ind=TRUE))
-        checkIdentical(target1, BLOCK_which(a))
+    do_which_tests <- function(svt, block_sizes) {
+        on.exit(suppressMessages(setAutoBlockSize()))
+        BLOCK_which <- DelayedArray:::BLOCK_which
+        a <- as.array(svt)
+        A <- DelayedArray(realize(a))
+        B <- DelayedArray(realize(svt))
+        target1 <- which(a)
+        target2 <- which(a, arr.ind=TRUE, useNames=FALSE)
+        ## TODO: Uncomment 4 tests below when which(<SVT_SparseArray>)
+        ## is ready.
+        for (block_size in block_sizes) {
+            suppressMessages(setAutoBlockSize(block_size))
+            checkIdentical(target1, which(A))
+            #checkIdentical(target1, which(B))
+            checkIdentical(target1, BLOCK_which(a))
+            #checkIdentical(target1, BLOCK_which(svt))
+            checkIdentical(target2, which(A, arr.ind=TRUE))
+            #checkIdentical(target2, which(B, arr.ind=TRUE))
+            checkIdentical(target2, BLOCK_which(a, arr.ind=TRUE))
+            #checkIdentical(target2, BLOCK_which(svt, arr.ind=TRUE))
+        }
     }
 
-    a <- a1 == -100L    # all FALSE
-    A <- realize(a)
-    target1 <- integer(0)
-    target2 <- matrix(integer(0), ncol=3)
-    for (block_size in .BLOCK_SIZES1) {
-        suppressMessages(setAutoBlockSize(block_size))
-        checkIdentical(target1, which(A))
-        checkIdentical(target2, which(A, arr.ind=TRUE))
-        checkIdentical(target1, BLOCK_which(a))
+    # logical 3D array
+    svt <- .make_toy_svt1() >= 1L
+    do_which_tests(svt, .BLOCK_SIZES1)
+
+    # logical 3D array with only FALSE/NA values
+    svt <- .make_toy_svt1() == -100L
+    do_which_tests(svt, .BLOCK_SIZES1)
+}
+
+test_DelayedArray_nzwhich <- function()
+{
+    do_nzwhich_tests <- function(svt, block_sizes) {
+        on.exit(suppressMessages(setAutoBlockSize()))
+        BLOCK_nzwhich <- DelayedArray:::BLOCK_nzwhich
+        a <- as.array(svt)
+        A <- DelayedArray(realize(a))
+        B <- DelayedArray(realize(svt))
+        target1 <- nzwhich(svt)
+        target2 <- nzwhich(svt, arr.ind=TRUE)
+        for (block_size in block_sizes) {
+            suppressMessages(setAutoBlockSize(block_size))
+            checkIdentical(target1, nzwhich(A))
+            checkIdentical(target1, nzwhich(B))
+            checkIdentical(target1, BLOCK_nzwhich(a))
+            checkIdentical(target1, BLOCK_nzwhich(svt))
+            checkIdentical(target2, nzwhich(A, arr.ind=TRUE))
+            checkIdentical(target2, nzwhich(B, arr.ind=TRUE))
+            checkIdentical(target2, BLOCK_nzwhich(a, arr.ind=TRUE))
+            checkIdentical(target2, BLOCK_nzwhich(svt, arr.ind=TRUE))
+        }
     }
+
+    # integer 3D array
+    svt1 <- .make_toy_svt1()
+    do_nzwhich_tests(svt1, .BLOCK_SIZES1)
+
+    # logical 3D array
+    do_nzwhich_tests(svt1 >= 1L, .BLOCK_SIZES1)
 }
 
 test_DelayedArray_Summary <- function()
@@ -269,7 +374,7 @@ test_DelayedArray_Summary <- function()
         GENERIC <- match.fun(.Generic)
         target1 <- GENERIC(a)
         target2 <- GENERIC(a, na.rm=TRUE)
-        A <- realize(a)
+        A <- DelayedArray(realize(a))
         for (block_size in block_sizes) {
             suppressMessages(setAutoBlockSize(block_size))
             checkFun(target1, GENERIC(A))
@@ -281,8 +386,8 @@ test_DelayedArray_Summary <- function()
         }
     }
 
-    a1 <- as.array(.make_toy_sas1())   # integer 3D array
-    a1b <- as.array(.make_toy_sas1b()) # integer 3D array with no zeros or NAs
+    a1 <- as.array(.make_toy_svt1())   # integer 3D array
+    a1b <- .make_toy_a1b()  # integer 3D array with no zeros or NAs
     a2 <- .make_toy_a2()  # numeric 3D array
     for (.Generic in c("max", "min", "range")) {
         do_tests(.Generic, a1, .BLOCK_SIZES1, checkIdentical)
@@ -312,7 +417,7 @@ test_DelayedArray_mean <- function()
         target1 <- mean(a)
         target2 <- mean(a, na.rm=TRUE)
         target3 <- mean(a[ , 10:4, -2])
-        A <- realize(a)
+        A <- DelayedArray(realize(a))
         for (block_size in block_sizes) {
             suppressMessages(setAutoBlockSize(block_size))
             checkEquals(target1, mean(A))
@@ -327,8 +432,8 @@ test_DelayedArray_mean <- function()
         }
     }
 
-    a1 <- as.array(.make_toy_sas1())   # integer 3D array
-    a1b <- as.array(.make_toy_sas1b()) # integer 3D array with no zeros or NAs
+    a1 <- as.array(.make_toy_svt1())   # integer 3D array
+    a1b <- .make_toy_a1b()  # integer 3D array with no zeros or NAs
     a2 <- .make_toy_a2()  # numeric 3D array
     do_tests(a1, .BLOCK_SIZES1)
     do_tests(a1b, .BLOCK_SIZES1)
@@ -339,7 +444,7 @@ test_DelayedArray_mean <- function()
 test_DelayedArray_apply <- function()
 {
     do_tests <- function(a) {
-        A <- realize(a)
+        A <- DelayedArray(realize(a))
         for (MARGIN in seq_along(dim(a))) {
             checkIdentical(apply(a, MARGIN, dim),
                            apply(A, MARGIN, dim))
@@ -361,7 +466,7 @@ test_DelayedArray_apply <- function()
         }
     }
 
-    a1b <- as.array(.make_toy_sas1b()) # integer 3D array with no zeros or NAs
+    a1b <- .make_toy_a1b()  # integer 3D array with no zeros or NAs
     do_tests(a1b)
     do_tests(a1b[ , , 0])
 
@@ -401,7 +506,7 @@ test_DelayedArray_scale <- function()
     m[4, 4] <- -Inf
     m[5:6, 5] <- c(NaN, Inf)
     m[6:8, 6] <- c(NaN, NA, -Inf)
-    M <- realize(m)
+    M <- DelayedArray(realize(m))
 
     ## 'center' is TRUE:
     target <- scale(m)
